import { IFnContext, IEnvInfo, IUserSource, IWxOpenApiParams, ICloudFnParams, IWedaApiParams } from '../types';
import { IConfig, IPrivateInfo } from '../config';
interface ISetCommonContext extends Pick<IConfig, 'entrance' | 'getDataSources'> {
    callDataSource: IFnContext['callDataSource'];
    callConnector: IFnContext['callDataSource'];
    callModel: IFnContext['callDataSource'];
    rawContext: any;
    /**
     * 云函数调用参数信息
     *  包括 { envType, wedaTarget, wx_xxxx, params} 等各种参数
     *  详见 packages/node-server/src/index.ts 中的 ICloudFnParams
     */
    cfnParams: ICloudFnParams;
    useAdmin?: boolean;
    wedaAccessToken?: string;
    privateInfo?: IPrivateInfo;
}
/** 公共的环境信息(与具体数据源无关的信息) */
declare type ICommonEnvInfo = Omit<IEnvInfo, 'dataSourceName' | 'dataSourceFullName'>;
/** 公共的context信息(与具体数据源无关的信息) */
declare type ICommonContext = Omit<IFnContext, 'method' | 'vars' | 'httpAuth' | 'env' | 'envInfo' | 'dataSourceProfile' | 'getCollectionName' | 'defaultParams' | 'collection'> & {
    env: ICommonEnvInfo;
    envInfo: ICommonEnvInfo;
    parsedRawContext: any;
    wedaAccessToken?: string;
    privateInfo?: IPrivateInfo;
};
export declare function getCommonContext(): ICommonContext | undefined;
/**
 * 设置公共的context
 */
export declare function setCommonContext(config: ISetCommonContext): Promise<{
    callDataSource: (options: import("../types").ICallDataSourceParams) => Promise<unknown>;
    callConnector: (options: import("../types").ICallDataSourceParams) => Promise<unknown>;
    callModel: (options: import("../types").ICallDataSourceParams) => Promise<unknown>;
    callWedaApi: (params: Omit<IWedaApiParams, 'envType'>) => Promise<any>;
    callWorkflow: (params: Omit<IWedaApiParams, 'envType'>) => Promise<any>;
    callWxOpenApi: (params: IWxOpenApiParams) => Promise<any>;
    cloudbase: typeof import("@cloudbase/node-sdk");
    app: import("@cloudbase/node-sdk").CloudBase;
    auth: {
        getUserInfo(): {
            openId: string;
            appId: string;
            uid: string;
            customUserId: string;
            isAnonymous: boolean;
        };
        getEndUserInfo(uid?: string | undefined, opts?: import("@cloudbase/node-sdk").ICustomReqOpts | undefined): Promise<any> | {
            userInfo: {
                openId: string;
                appId: string;
                uid: string;
                customUserId: string;
                isAnonymous: boolean;
            };
        };
        getAuthContext(context: import("@cloudbase/node-sdk").IContextParam): Promise<import("@cloudbase/node-sdk").IGetAuthContextRes>;
        getClientIP(): string;
        createTicket: (uid: string, options?: import("@cloudbase/node-sdk").ICreateTicketOpts | undefined) => string;
    };
    env: ICommonEnvInfo;
    envInfo: ICommonEnvInfo;
    database: import("@cloudbase/node-sdk").Database.Db;
    weixin: Record<string, any> | null;
    wedaTarget: string | undefined;
    extraHeaders: any;
    parsedRawContext: import("@cloudbase/node-sdk").ISCFContext;
    wedaAccessToken: string | undefined;
    privateInfo: {
        isPrivate: any;
        fetchUrl: any;
    };
}>;
/** 获取用户来源信息 */
export declare function getUserSourceCache(envInfo: ICommonEnvInfo, config: ISetCommonContext): Promise<IUserSource | undefined>;
export {};
